#' rt_calc
#'
#' @param data a dataframe with the following columns - date, individual, well, sample, genotype,
#' condition, bio_replicate, target, Ct, primer_1 and primer_2.
#' @description Creates table summary Ct values for appedicies.
#'
#' @export
rt_calc <- function(data){

  require(tidyverse)
  require(checkmate)

  # Check data
  assertNames(names(data), identical.to =  c("date", "individual", "well", "sample", "genotype",
                                             "condition", "bio_replicate", "target", "Ct",
                                             "primer_1", "primer_2"),
              .var.name = "data")

  data %>%
    select(target, sample, genotype, bio_replicate, Ct) %>%
    group_by(sample, bio_replicate, target) %>%
    summarise(Mean_Ct = mean(Ct), Min_Ct = min(Ct), Max_Ct = max(Ct)) %>%
    mutate_if(is.numeric, round, digits = 2) %>%
    unite(Range, Min_Ct, Max_Ct, sep = "-") %>%
    gather(variable, value, -sample, -target, -bio_replicate) %>%
    unite(variable, target, variable) %>%
    spread(variable, value) %>%

    left_join(data %>%
                rt_summary() %>%
                rt_test()) %>%

    select(sample, genotype, everything(), -condition, -data)
}
