#' rt_summary
#'
#' @param data a dataframe with the following columns - date, individual, well, sample, genotype,
#' condition, bio_replicate, target, Ct, primer_1 and primer_2.
#'
#' @description Groups away technical replicates calculating the mean. In addition takes the
#' standard deviation and divides in by the mean and checks if it is 0.015 which is a rule of thumb.
#'
#' @export
rt_summary <- function(data){

  require(dplyr)
  require(checkmate)

  assertNames(names(data), identical.to =  c("date", "individual", "well", "sample", "genotype",
                                             "condition", "bio_replicate", "target", "Ct",
                                             "primer_1", "primer_2"),
              .var.name = "data")

  data %>%
    select(date, sample, genotype, condition, bio_replicate, target, Ct) %>%
    group_by(date, target, sample, genotype, condition, bio_replicate) %>%
    summarise(mean_ct = mean(Ct), sd_div_mean = sd(Ct)/mean(Ct)) %>%
    mutate(sd_check = sd_div_mean < 0.015)
}
